
import com.phidget22.*;

public class SoundSensorExample {

    public static void main(String[] args) throws Exception {
        //Enable logging to stdout
        com.phidget22.Log.enable(LogLevel.INFO, null);
        
        SoundSensor ch = new SoundSensor();

        ch.addAttachListener(new AttachListener() {
				public void onAttach(AttachEvent ae) {
				SoundSensor phid = (SoundSensor) ae.getSource();
				try {
					if(phid.getDeviceClass() != DeviceClass.VINT){
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " attached");
					}
					else{
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " hub port " + phid.getHubPort() + " attached");
					}
				} catch (PhidgetException ex) {
					System.out.println(ex.getDescription());
				}
			}
        });

        ch.addDetachListener(new DetachListener() {
				public void onDetach(DetachEvent de) {
				SoundSensor phid = (SoundSensor) de.getSource();
				try {
					if (phid.getDeviceClass() != DeviceClass.VINT) {
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " detached");
					} else {
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " hub port " + phid.getHubPort() + " detached");
					}
				} catch (PhidgetException ex) {
					System.out.println(ex.getDescription());
				}
			}
        });

        ch.addErrorListener(new ErrorListener() {
			public void onError(ErrorEvent ee) {
				System.out.println("Error: " + ee.getDescription());
			}
        });

        ch.addSPLChangeListener(new SoundSensorSPLChangeListener() {
			public void onSPLChange(SoundSensorSPLChangeEvent e) {
				double octaves[];
				octaves = e.getOctaves();
				System.out.printf("---------------------------------\n");
				System.out.printf("SPL Changed: %7.3f %7.3f %7.3f\n", e.getDB(), e.getDBA(), e.getDBC());
				System.out.printf("32Hz : %.3f\n", octaves[0]);
				System.out.printf("63Hz : %.3f\n", octaves[1]);
				System.out.printf("125Hz: %.3f\n", octaves[2]);
				System.out.printf("250Hz: %.3f\n", octaves[3]);
				System.out.printf("500Hz: %.3f\n", octaves[4]);
				System.out.printf("1kHz : %.3f\n", octaves[5]);
				System.out.printf("2kHz : %.3f\n", octaves[6]);
				System.out.printf("4kHz : %.3f\n", octaves[7]);
				System.out.printf("8kHz : %.3f\n", octaves[8]);
				System.out.printf("16kHz: %.3f\n", octaves[9]);
			}
        });

        try {
             /*
            * Please review the Phidget22 channel matching documentation for details on the device
            * and class architecture of Phidget22, and how channels are matched to device features.
            */

            /*
            * Specifies the serial number of the device to attach to.
            * For VINT devices, this is the hub serial number.
            *
            * The default is any device.
            */
            //ch.setDeviceSerialNumber(<YOUR DEVICE SERIAL NUMBER>);
            /*
            * For VINT devices, this specifies the port the VINT device must be plugged into.
            *
            * The default is any port.
            */
            //ch.setHubPort(0);

            /*
            * Specifies that the channel should only match a VINT hub port.
            * The only valid channel id is 0.
            *
            * The default is 0 (false), meaning VINT hub ports will never match
            */
             //ch.setIsHubPortDevice(true);

            /*
            * Specifies which channel to attach to.  It is important that the channel of
            * the device is the same class as the channel that is being opened.
            *
            * The default is any channel.
            */
            //ch.setChannel(0);

            /*
            * In order to attach to a network Phidget, the program must connect to a Phidget22 Network Server.
            * In a normal environment this can be done automatically by enabling server discovery, which
            * will cause the client to discovery and connect to available servers.
            *
            * To force the channel to only match a network Phidget, set remote to 1.
            */
            // Net.enableServerDiscovery(ServerType.DEVICE);
            // ch.setIsRemote(true);

            System.out.println("Opening and waiting 5 seconds for attachment...");
            ch.open(5000);
            
            System.out.println("\n\nGathering data for 10 seconds\n\n");
            Thread.sleep(10000);

            ch.close();
            System.out.println("\nClosed SoundSensor");
            
        } catch (PhidgetException ex) {
            System.out.println(ex.getDescription());
        }
    }
}
